==> w3ml-0.1-20000614.tar.gz: w3ml-0.1-20000614/setup.rb <==
D = {
  'RUBY_PATH' => '/usr/local/bin/ruby',
  'DATA_DIR' => '/usr/local/w3ml',
  'CGI_DIR' => nil,
  'ML' => nil,
  'UseMysql' => 'no',
  'MysqlHost' => '',
  'MysqlUser' => '',
  'MysqlPass' => '',
  'MysqlDB' => 'w3ml'
}

Files = ['entry', 'index.cgi', 'list.cgi', 'msg.cgi', 'thread.cgi',
  'attach.cgi', 'search.cgi', 'conf', 'w3ml.rb', 'w3ml_mysql.rb']

if File::exist? 'setup.cache' then
  File::open('setup.cache').each do |r|
    a = r.split /\t/, 2
    D[a[0]] = a[1].chomp
  end
end

def prompt(str, var)
  begin
    print "#{str} [#{D[var]}] "
    $stdout.flush
    r = $stdin.gets.chomp
    if r != "" then
      D[var] = r
    end
  end while D[var] == nil
end

def setup()
  prompt 'Ruby path', 'RUBY_PATH'
  prompt 'Data directory', 'DATA_DIR'
  prompt 'CGI directory', 'CGI_DIR'
  prompt 'ML name', 'ML'
  prompt 'Use MySQL?', 'UseMysql'
  if D['UseMysql'] =~ /^y/i then
    prompt 'MySQL server hostname', 'MysqlHost'
    prompt 'MySQL username', 'MysqlUser'
    prompt 'MySQL password', 'MysqlPass'
    prompt 'MySQL Database', 'MysqlDB'
  end

  File::open('setup.cache', 'w') do |f|
    D.keys.each do |k|
      f.puts "#{k}\t#{D[k]}"
    end
  end

  Files.each do |f|
    if File::exist? "#{f}.in" then
      w = File::open(f, "w")
      w.write File::open("#{f}.in").read.gsub(/@(\w+)@/) do |s|
	if D.has_key? $1 then
	  D[$1]
	else
	  s
	end
      end
    end
  end
  system "chmod +x entry *.cgi"
end

def install()
  if not File::exist? 'conf' or not File::exist? 'entry' then
    setup
  end

  if not File::directory? D['DATA_DIR'] then
    Dir::mkdir D['DATA_DIR']
  end
  if not File::directory? D['CGI_DIR'] then
    Dir::mkdir D['CGI_DIR']
  end

  system "cp -f conf entry tmail+.rb w3ml.rb w3ml_mime.rb #{D['DATA_DIR']}"
  system "cp -f w3ml_mysql.rb #{D['DATA_DIR']}/w3ml.rb" if D['UseMysql'] =~ /^y/i
  system "cp -f index.cgi list.cgi thread.cgi msg.cgi attach.cgi search.cgi w3ml.css #{D['CGI_DIR']}"
end

def usage()
  puts 'usage: ruby setup.rb {setup|install}'
  exit 1
end

if ARGV.length != 1 then
  usage
end

case ARGV[0]
when 'setup' then setup
when 'install' then install
else
  usage
end

if D['UseMysql'] =~ /^y/ then
  puts
  puts "Please create database `#{D['MysqlDB']}' on MySQL"
  puts "and create tables using `db.sql' file."
  puts
end

==> w3ml-0.2-20000814.tar.gz: w3ml-0.2-20000814/setup.rb <==
#!/usr/local/bin/ruby
#

D = {
  'RUBY_PATH' => '/usr/local/bin/ruby',
  'DATA_DIR' => '/usr/local/w3ml',
  'CGI_DIR' => nil,
  'CSS_DIR' => nil,
  'CSS_URL' => nil,
  'ML' => nil,
  'UseMysql' => 'no',
  'MysqlHost' => '',
  'MysqlUser' => '',
  'MysqlPass' => '',
  'MysqlDB' => 'w3ml'
}

Files = ['entry', 'index.cgi', 'list.cgi', 'msg.cgi', 'thread.cgi',
  'attach.cgi', 'search.cgi', 'conf', 'w3ml.rb', 'w3ml_mysql.rb']

ENV['PATH'].split(/:/).each do |p|
  if File::executable? p+'/ruby' then
    D['RUBY_PATH'] = p+'/ruby'
    break
  end
end

if File::exist? 'setup.cache' then
  File::open('setup.cache').each do |r|
    a = r.split /\t/, 2
    D[a[0]] = a[1].chomp
  end
end

def prompt(str, var)
  begin
    print "#{str} [#{D[var]}] "
    $stdout.flush
    r = $stdin.gets.chomp
    if r != "" then
      D[var] = r
    end
  end while D[var] == nil
end

def setup()
  prompt 'ML name', 'ML'
  prompt 'Ruby path', 'RUBY_PATH'
  prompt 'Data directory', 'DATA_DIR'
  prompt 'CGI directory', 'CGI_DIR'
  prompt 'CSS directory (Real Path)', 'CSS_DIR'
  prompt 'CSS directory (URL)', 'CSS_URL'
  prompt 'Use MySQL?', 'UseMysql'
  if D['UseMysql'] =~ /^y/i then
    prompt 'MySQL server hostname', 'MysqlHost'
    prompt 'MySQL username', 'MysqlUser'
    prompt 'MySQL password', 'MysqlPass'
    prompt 'MySQL Database', 'MysqlDB'
  end

  File::open('setup.cache', 'w') do |f|
    D.keys.each do |k|
      f.puts "#{k}\t#{D[k]}"
    end
  end

  Files.each do |f|
    if File::exist? "#{f}.in" then
      w = File::open(f, "w")
      w.write File::open("#{f}.in").read.gsub(/@(\w+)@/) do |s|
	if D.has_key? $1 then
	  D[$1]
	else
	  s
	end
      end
    end
  end
  system "chmod +x entry *.cgi"
end

def install()
  if not File::exist? 'conf' or not File::exist? 'entry' then
    setup
  end

  Dir::mkdir D['DATA_DIR'] if not File::directory? D['DATA_DIR']
  Dir::mkdir D['CGI_DIR'] if not File::directory? D['CGI_DIR']
  Dir::mkdir D['CSS_DIR'] if not File::directory? D['CSS_DIR']

  system "cp -f conf entry w3ml.rb umail.rb #{D['DATA_DIR']}"
  system "cp -f w3ml_mysql.rb #{D['DATA_DIR']}/w3ml.rb" if D['UseMysql'] =~ /^y/i
  system "cp -f index.cgi list.cgi thread.cgi msg.cgi attach.cgi search.cgi #{D['CGI_DIR']}"
  system "cp -f w3ml.css #{D['CSS_DIR']}"
end

def usage()
  puts 'usage: ruby setup.rb {setup|install}'
  exit 1
end

if ARGV.length != 1 then
  usage
end

case ARGV[0]
when 'setup' then setup
when 'install' then
  install
  if D['UseMysql'] =~ /^y/ then
    puts
    puts "Please create database `#{D['MysqlDB']}' on MySQL"
    puts "and create tables using `db.sql' file."
    puts
  end
else
  usage
end
